@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2003 Imendio HB
+ * Copyright (C) 2003 Imendio AB
  * Copyright (C) 2002 CodeFactory AB
  * Copyright (C) 2002 Richard Hult <richard@imendio.com>
  * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
@@ -24,14 +24,10 @@
 #ifndef __PLANNER_APPLICATION_H__
 #define __PLANNER_APPLICATION_H__
 
-#include <bonobo/bonobo-window.h>
-#include <bonobo/bonobo-ui-component.h>
-#include <gconf/gconf-client.h>
 #include <libplanner/mrp-application.h>
 #include <libplanner/mrp-project.h>
 #include <libegg/recent-files/egg-recent-model.h>
 
-
 #define PLANNER_TYPE_APPLICATION                (planner_application_get_type ())
 #define PLANNER_APPLICATION(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLANNER_TYPE_APPLICATION, PlannerApplication))
 #define PLANNER_APPLICATION_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), PLANNER_TYPE_APPLICATION, PlannerApplicationClass))
@@ -59,7 +55,5 @@ PlannerApplication   *planner_application_new              (void);
 GtkWidget       *     planner_application_new_window       (PlannerApplication *app);
 void                  planner_application_exit             (PlannerApplication *app);
 EggRecentModel  *     planner_application_get_recent_model (PlannerApplication *app);
-GConfClient     *     planner_application_get_gconf_client (void);
-
 
 #endif /* __PLANNER_APPLICATION_H__ */
