@@ -29,6 +29,7 @@
 #include <libplanner/mrp-day.h>
 #include <libplanner/mrp-object.h>
 #include <libplanner/mrp-project.h>
+#include <libplanner/mrp-paths.h>
 #include "planner-calendar.h"
 #include "planner-working-time-dialog.h"
 #include "planner-default-week-dialog.h"
@@ -587,12 +588,17 @@ planner_calendar_dialog_new (PlannerWindow *window)
 	GtkWidget        *w;
 	GtkTreeSelection *selection;
 	gint              i;
+	gchar		*filename;
 	
-	g_return_val_if_fail (PLANNER_IS_MAIN_WINDOW (window), NULL);
+	g_return_val_if_fail (PLANNER_IS_WINDOW (window), NULL);
 	
-	glade = glade_xml_new (GLADEDIR "/calendar-dialog.glade",
+	filename = mrp_paths_get_glade_dir ("calendar-dialog.glade");
+	glade = glade_xml_new (filename ,
 			       "calendar_dialog",
 			       GETTEXT_PACKAGE);
+	
+	g_free (filename);
+	
 	if (!glade) {
 		g_warning ("Could not create calendar dialog.");
 		return NULL;
@@ -871,8 +877,9 @@ cal_dialog_update_calendar_widgets (DialogData *data)
 	MrpCalendar *calendar;
 	PlannerCalendar  *calendar_widget;
 	guint        y, m, d;
-	mrptime      t;
 	MrpDay      *day;
+	MrpTime      *t;
+	mrptime      time;
 	
 	calendar = cal_dialog_get_selected_calendar (GTK_TREE_VIEW (data->tree_view));
 	if (!calendar) {
@@ -890,10 +897,14 @@ cal_dialog_update_calendar_widgets (DialogData *data)
 
 	planner_calendar_get_date (calendar_widget, &y, &m, &d);
 
+	t = mrp_time2_new ();
+	mrp_time2_set_date (t, y, m+1, 1);
+	mrp_time2_set_time (t, 0, 0, 0);
+
 	for (d = 1; d <= 31; d++) {
-		t = mrp_time_compose (y, m + 1, d, 0, 0, 0);
-		
-		day = mrp_calendar_get_day (calendar, t, TRUE);
+		time = mrp_time2_get_epoch (t);
+
+		day = mrp_calendar_get_day (calendar, time, TRUE);
 
 		if (day == mrp_day_get_nonwork ()) {
 			planner_calendar_mark_day (calendar_widget,
@@ -905,7 +916,10 @@ cal_dialog_update_calendar_widgets (DialogData *data)
 						   d,
 						   PLANNER_CALENDAR_MARK_NONE);
 		}
+
+		mrp_time2_add_days (t, 1);
 	}
+	mrp_time2_free (t);
 }
 
 static void
@@ -1246,10 +1260,13 @@ cal_dialog_new_dialog_run (DialogData *data)
 	GtkWidget        *tree_view;
 	const gchar      *name;
 	GtkTreePath      *path;
+	gchar            *filename;
 	
-	glade = glade_xml_new (GLADEDIR "/calendar-dialog.glade",
+	filename = mrp_paths_get_glade_dir ("calendar-dialog.glade");
+	glade = glade_xml_new (filename,
 			       "new_calendar_dialog",
 			       GETTEXT_PACKAGE);
+	g_free (filename);
 
 	dialog = glade_xml_get_widget (glade, "new_calendar_dialog");
 
