@@ -29,6 +29,7 @@
 #include <unistd.h>
 #include <string.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-job.h>
@@ -55,7 +56,7 @@ ensure_dir (void)
 	dir = g_build_filename (g_get_home_dir (), ".gnome2", NULL);
 	
 	if (!g_file_test (dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
-		if (mkdir (dir, 0755) != 0) {
+		if (g_mkdir (dir, 0755) != 0) {
 			g_free (dir);
 			return FALSE;
 		}
@@ -66,7 +67,7 @@ ensure_dir (void)
 	dir = g_build_filename (g_get_home_dir (), ".gnome2", "planner", NULL);
 	
 	if (!g_file_test (dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
-		if (mkdir (dir, 0755) != 0) {
+		if (g_mkdir (dir, 0755) != 0) {
 			g_free (dir);
 			return FALSE;
 		}
@@ -152,6 +153,29 @@ planner_print_dialog_save_config (GnomePrintConfig *config)
 	}
 }
 
+GtkWidget *
+planner_print_views_dialog_new (PlannerWindow  *window,
+			  GList          *views)
+{
+	GtkWidget *dialog;
+	GtkWidget *page;
+	
+	dialog = gtk_dialog_new_with_buttons ("Select Views",
+						GTK_WINDOW (window),
+						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						GTK_STOCK_OK,
+						GTK_RESPONSE_OK,
+						GTK_STOCK_CANCEL,
+						GTK_RESPONSE_CANCEL,
+						NULL); 
+	page = print_dialog_create_page (window, dialog, views);
+
+	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), page);
+
+	gtk_widget_show_all (dialog);
+
+	return dialog;
+}	
 GtkWidget *
 planner_print_dialog_new (PlannerWindow  *window,
 			  GnomePrintJob  *job,
@@ -168,6 +192,7 @@ planner_print_dialog_new (PlannerWindow  *window,
 	gtk_notebook_prepend_page (print_dialog_get_notebook (dialog),
 				   page,
 				   gtk_label_new (_("Select views")));
+	gtk_notebook_set_current_page (print_dialog_get_notebook (dialog), 0);
 
 	g_object_set_data (G_OBJECT (dialog), "window", window);
 
